package com.ruoyi.ai.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ai.mapper.AiRechargeGiftRecordMapper;
import com.ruoyi.ai.domain.AiRechargeGiftRecord;
import com.ruoyi.ai.service.IAiRechargeGiftRecordService;

/**
 * 充值赠送记录Service业务层处理
 * 
 * @author shi
 * @date 2025-11-20
 */
@Service
public class AiRechargeGiftRecordServiceImpl implements IAiRechargeGiftRecordService {

    @Autowired
    private AiRechargeGiftRecordMapper aiRechargeGiftRecordMapper;

    /**
     * 查询充值赠送记录
     * 
     * @param id 充值赠送记录主键
     * @return 充值赠送记录
     */
    @Override
    public AiRechargeGiftRecord selectAiRechargeGiftRecordById(Long id) {
        return aiRechargeGiftRecordMapper.selectById(id);
    }

    /**
     * 查询充值赠送记录列表
     * 
     * @param aiRechargeGiftRecord 充值赠送记录
     * @return 充值赠送记录
     */
    @Override
    public List<AiRechargeGiftRecord> selectAiRechargeGiftRecordList(AiRechargeGiftRecord aiRechargeGiftRecord) {
        return aiRechargeGiftRecordMapper.selectAiRechargeGiftRecordList(aiRechargeGiftRecord);
    }

    /**
     * 分页查询充值赠送记录列表
     *
     * @param aiRechargeGiftRecord 充值赠送记录
     * @return 充值赠送记录
     */
    @Override
    public IPage<AiRechargeGiftRecord> selectAiRechargeGiftRecordPage(Page page, AiRechargeGiftRecord aiRechargeGiftRecord) {
        LambdaQueryWrapper<AiRechargeGiftRecord> query = Wrappers.lambdaQuery(aiRechargeGiftRecord);
        query.eq(AiRechargeGiftRecord::getDelFlag, "0");
        return aiRechargeGiftRecordMapper.selectPage(page, query);
    }

    /**
     * 新增充值赠送记录
     * 
     * @param aiRechargeGiftRecord 充值赠送记录
     * @return 结果
     */
    @Override
    public int insertAiRechargeGiftRecord(AiRechargeGiftRecord aiRechargeGiftRecord) {
        aiRechargeGiftRecord.setDelFlag("0");
//        aiRechargeGiftRecord.setCreateBy(SecurityUtils.getUsername());
        aiRechargeGiftRecord.setCreateTime(DateUtils.getNowDate());
        return aiRechargeGiftRecordMapper.insert(aiRechargeGiftRecord);
    }

    /**
     * 修改充值赠送记录
     * 
     * @param aiRechargeGiftRecord 充值赠送记录
     * @return 结果
     */
    @Override
    public int updateAiRechargeGiftRecord(AiRechargeGiftRecord aiRechargeGiftRecord) {
        aiRechargeGiftRecord.setUpdateBy(SecurityUtils.getUsername());
        aiRechargeGiftRecord.setUpdateTime(DateUtils.getNowDate());
        return aiRechargeGiftRecordMapper.updateById(aiRechargeGiftRecord);
    }

    /**
     * 批量删除充值赠送记录
     * 
     * @param ids 需要删除的充值赠送记录主键
     * @return 结果
     */
    @Override
    public int deleteAiRechargeGiftRecordByIds(Long[] ids)
    {
        return aiRechargeGiftRecordMapper.deleteAiRechargeGiftRecordByIds(ids);
    }

    /**
     * 删除充值赠送记录信息
     * 
     * @param id 充值赠送记录主键
     * @return 结果
     */
    @Override
    public int deleteAiRechargeGiftRecordById(Long id)
    {
        return aiRechargeGiftRecordMapper.deleteAiRechargeGiftRecordById(id);
    }
}
